==> haskell-filepath-bytestring-1.4.2.1.6-79-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepath-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filepath-bytestring
version:              1.4.2.1.6
visibility:           public
id:                   filepath-bytestring-1.4.2.1.6-B3iiULLnuV06S3bEGRIlGM
key:                  filepath-bytestring-1.4.2.1.6-B3iiULLnuV06S3bEGRIlGM
license:              BSD-3-Clause
copyright:
    Neil Mitchell 2005-2019
    Joey Hess 2019

maintainer:           Joey Hess <id@joeyh.name>
author:               Neil Mitchell <ndmitchell@gmail.com>
synopsis:
    Library for manipulating RawFilePaths in a cross platform way.

description:
    This package provides functionality for manipulating @RawFilePath@
    values. It can be used as a drop in replacement for the filepath library
    to get the benefits of using ByteStrings. It provides three modules:

    * "System.FilePath.Posix.ByteString" manipulates POSIX\/Linux style @RawFilePath@ values (with @\/@ as the path separator).

    * "System.FilePath.Windows.ByteString" manipulates Windows style @RawFilePath@ values (with either @\\@ or @\/@ as the path separator, and deals with drives).

    * "System.FilePath.ByteString" is an alias for the module appropriate to your platform.

    All three modules provide the same API, and the same documentation (calling out differences in the different variants).

category:             System
abi:                  ac2ed2e201fb6930e8b7c80f1fb684b3
exposed:              True
exposed-modules:
    System.FilePath.ByteString System.FilePath.Posix.ByteString
    System.FilePath.Windows.ByteString

import-dirs:
    /usr/lib/ghc-8.10.4/site-local/filepath-bytestring-1.4.2.1.6

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/filepath-bytestring-1.4.2.1.6

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/filepath-bytestring-1.4.2.1.6

hs-libraries:         HSfilepath-bytestring-1.4.2.1.6-B3iiULLnuV06S3bEGRIlGM
depends:              base-4.14.1.0 bytestring-0.10.12.0 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-filepath-bytestring/html/filepath-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-filepath-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filepath-bytestring-1.4.2.1.6-81-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filepath-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filepath-bytestring
version:              1.4.2.1.6
visibility:           public
id:                   filepath-bytestring-1.4.2.1.6-3VPeeNTtG8G9lvaF2aVCaQ
key:                  filepath-bytestring-1.4.2.1.6-3VPeeNTtG8G9lvaF2aVCaQ
license:              BSD-3-Clause
copyright:
    Neil Mitchell 2005-2019
    Joey Hess 2019

maintainer:           Joey Hess <id@joeyh.name>
author:               Neil Mitchell <ndmitchell@gmail.com>
synopsis:
    Library for manipulating RawFilePaths in a cross platform way.

description:
    This package provides functionality for manipulating @RawFilePath@
    values. It can be used as a drop in replacement for the filepath library
    to get the benefits of using ByteStrings. It provides three modules:

    * "System.FilePath.Posix.ByteString" manipulates POSIX\/Linux style @RawFilePath@ values (with @\/@ as the path separator).

    * "System.FilePath.Windows.ByteString" manipulates Windows style @RawFilePath@ values (with either @\\@ or @\/@ as the path separator, and deals with drives).

    * "System.FilePath.ByteString" is an alias for the module appropriate to your platform.

    All three modules provide the same API, and the same documentation (calling out differences in the different variants).

category:             System
abi:                  d41c2c09aed48bea279fff80fe2cd42e
exposed:              True
exposed-modules:
    System.FilePath.ByteString System.FilePath.Posix.ByteString
    System.FilePath.Windows.ByteString

import-dirs:
    /usr/lib/ghc-8.10.4/site-local/filepath-bytestring-1.4.2.1.6

library-dirs:
    /usr/lib/ghc-8.10.4/site-local/filepath-bytestring-1.4.2.1.6

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/filepath-bytestring-1.4.2.1.6

hs-libraries:         HSfilepath-bytestring-1.4.2.1.6-3VPeeNTtG8G9lvaF2aVCaQ
depends:              base-4.14.1.0 bytestring-0.10.12.0 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-filepath-bytestring/html/filepath-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-filepath-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
